@@ -35,8 +35,8 @@ class Test:
         os.makedirs("src")
         copy("src/demo_shtab.py", "src")
         generate()
-        for file in list(os.walk("build/resources"))[0][-1]:
-            with open(os.path.join("build/resources", file)) as f:
+        for file in list(os.walk("sdist"))[0][-1]:
+            with open(os.path.join("sdist", file)) as f:
                 rst = f.read()
             assert rst != ""
 
